@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 wsproto/connection
 ~~~~~~~~~~~~~~~~~~
@@ -106,7 +105,7 @@ class Connection:
             else:
                 self._state = ConnectionState.LOCAL_CLOSING
         else:
-            raise LocalProtocolError("Event {} cannot be sent.".format(event))
+            raise LocalProtocolError(f"Event {event} cannot be sent.")
         return data
 
     def receive_data(self, data: Optional[bytes]) -> None:
@@ -133,6 +132,8 @@ class Connection:
             self._proto.receive_bytes(data)
         elif self.state is ConnectionState.CLOSED:
             raise LocalProtocolError("Connection already closed.")
+        else:
+            pass  # pragma: no cover
 
     def events(self) -> Generator[Event, None, None]:
         """
@@ -180,5 +181,8 @@ class Connection:
                         frame_finished=frame.frame_finished,
                         message_finished=frame.message_finished,
                     )
+
+                else:
+                    pass  # pragma: no cover
         except ParseFailed as exc:
             yield CloseConnection(code=exc.code, reason=str(exc))
