@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 wsproto/handshake
 ~~~~~~~~~~~~~~~~~~
@@ -6,7 +5,17 @@ wsproto/handshake
 An implementation of WebSocket handshakes.
 """
 from collections import deque
-from typing import Deque, Dict, Generator, List, Optional, Union
+from typing import (
+    cast,
+    Deque,
+    Dict,
+    Generator,
+    Iterable,
+    List,
+    Optional,
+    Sequence,
+    Union,
+)
 
 import h11
 
@@ -98,7 +107,7 @@ class H11Handshake:
             data += self._send_reject_data(event)
         else:
             raise LocalProtocolError(
-                "Event {} cannot be sent during the handshake".format(event)
+                f"Event {event} cannot be sent during the handshake"
             )
         return data
 
@@ -215,7 +224,7 @@ class H11Handshake:
                 "Missing header, 'Sec-WebSocket-Version'",
                 event_hint=RejectConnection(
                     headers=[(b"Sec-WebSocket-Version", WEBSOCKET_VERSION)],
-                    status_code=426,
+                    status_code=426 if version else 400,
                 ),
             )
         if key is None:
@@ -226,10 +235,6 @@ class H11Handshake:
             raise RemoteProtocolError(
                 "Missing header, 'Upgrade: WebSocket'", event_hint=RejectConnection()
             )
-        if version is None:
-            raise RemoteProtocolError(
-                "Missing header, 'Sec-WebSocket-Version'", event_hint=RejectConnection()
-            )
         if host is None:
             raise RemoteProtocolError(
                 "Missing header, 'Host'", event_hint=RejectConnection()
@@ -260,16 +265,15 @@ class H11Handshake:
 
         if event.subprotocol is not None:
             if event.subprotocol not in self._initiating_request.subprotocols:
-                raise LocalProtocolError(
-                    "unexpected subprotocol {}".format(event.subprotocol)
-                )
+                raise LocalProtocolError(f"unexpected subprotocol {event.subprotocol}")
             headers.append(
                 (b"Sec-WebSocket-Protocol", event.subprotocol.encode("ascii"))
             )
 
         if event.extensions:
-            accepts = server_extensions_handshake(  # type: ignore
-                self._initiating_request.extensions, event.extensions
+            accepts = server_extensions_handshake(
+                cast(Sequence[str], self._initiating_request.extensions),
+                event.extensions,
             )
             if accepts:
                 headers.append((b"Sec-WebSocket-Extensions", accepts))
@@ -304,7 +308,7 @@ class H11Handshake:
     def _send_reject_data(self, event: RejectData) -> bytes:
         if self.state != ConnectionState.REJECTING:
             raise LocalProtocolError(
-                "Cannot send rejection data in state {}".format(self.state)
+                f"Cannot send rejection data in state {self.state}"
             )
 
         data = self._h11_connection.send(h11.Data(data=event.data))
@@ -336,15 +340,18 @@ class H11Handshake:
             )
 
         if request.extensions:
-            offers = {e.name: e.offer() for e in request.extensions}  # type: ignore
+            offers: Dict[str, Union[str, bool]] = {}
+            for e in request.extensions:
+                assert isinstance(e, Extension)
+                offers[e.name] = e.offer()
             extensions = []
             for name, params in offers.items():
-                name = name.encode("ascii")
+                bname = name.encode("ascii")
                 if isinstance(params, bool):
                     if params:
-                        extensions.append(name)
+                        extensions.append(bname)
                 else:
-                    extensions.append(b"%s; %s" % (name, params.encode("ascii")))
+                    extensions.append(b"%s; %s" % (bname, params.encode("ascii")))
             if extensions:
                 headers.append((b"Sec-WebSocket-Extensions", b", ".join(extensions)))
 
@@ -404,11 +411,11 @@ class H11Handshake:
             subprotocol = subprotocol.decode("ascii")
             if subprotocol not in self._initiating_request.subprotocols:
                 raise RemoteProtocolError(
-                    "unrecognized subprotocol {}".format(subprotocol),
+                    f"unrecognized subprotocol {subprotocol}",
                     event_hint=RejectConnection(),
                 )
-        extensions = client_extensions_handshake(  # type: ignore
-            accepts, self._initiating_request.extensions
+        extensions = client_extensions_handshake(
+            accepts, cast(Sequence[Extension], self._initiating_request.extensions)
         )
 
         self._connection = Connection(
@@ -428,7 +435,7 @@ class H11Handshake:
 
 
 def server_extensions_handshake(
-    requested: List[str], supported: List[Extension]
+    requested: Iterable[str], supported: List[Extension]
 ) -> Optional[bytes]:
     """Agree on the extensions to use returning an appropriate header value.
 
@@ -464,7 +471,7 @@ def server_extensions_handshake(
 
 
 def client_extensions_handshake(
-    accepted: List[str], supported: List[Extension]
+    accepted: Iterable[str], supported: Sequence[Extension]
 ) -> List[Extension]:
     # This raises RemoteProtocolError is the accepted extension is not
     # supported.
@@ -478,6 +485,6 @@ def client_extensions_handshake(
                 break
         else:
             raise RemoteProtocolError(
-                "unrecognized extension {}".format(name), event_hint=RejectConnection()
+                f"unrecognized extension {name}", event_hint=RejectConnection()
             )
     return extensions
